.. ``kedro-serving`` documentation main file, created by
   sphinx-quickstart on Mon Jul 13 14:21:13 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kedro-serving's documentation!
========================================

.. toctree::
   :maxdepth: 4

   First doc <source/01_introduction/index.rst>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
